@@ -1,5 +1,6 @@
 package Date::Ethiopic::ET;
 
+use utf8;
 BEGIN
 {
 	require 5.000;
@@ -179,7 +180,7 @@ __END__
 
 =head1 NAME
 
-Date::Ethiopic::ET - Ethiopian Calendar Data for Date::Ethiopic.
+Date::Ethiopic::ET - Ethiopian Calendar Data for L<Date::Ethiopic>.
 
 =head1 DESCRIPTION
 
@@ -207,6 +208,6 @@ to comment out this line.
 
 =head1 AUTHOR
 
-Daniel Yacob,  L<Yacob@EthiopiaOnline.Net|mailto:Yacob@EthiopiaOnline.Net>
+Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
 =cut
