@@ -70,7 +70,7 @@ __END__
 
 =head1 NAME
 
-Date::Ethiopic::ET::gru - Sodo Calendar Date for Date::Ethiopic.
+Date::Ethiopic::ET::gru - Sodo Calendar Date for L<Date::Ethiopic>.
 
 =head1 SYNOPSIS
 
@@ -136,11 +136,11 @@ This module is free software; you can redistribute it and/or modify it under the
 
 =head1 BUGS
 
-None known yet.
+None presently known.
 
 =head1 AUTHOR
 
-Daniel Yacob,  L<Yacob@EthiopiaOnline.Net|mailto:Yacob@EthiopiaOnline.Net>
+Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
 =head1 SEE ALSO
 
